/**
 * JASMINe Deploy ME [Managed Element]
 * Copyright (C) 2012 Bull S.A.S.
 * Copyright (C) 2012 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Web.java 10000 2012-05-02 14:52:40Z cazauxj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.deployme.module.web;

import org.ow2.jasmine.deployme.module.AbstractDeploymeModule;
import org.ow2.jasmine.deployme.api.modules.UnsupportDeploymeModuleException;
import org.ow2.jonas.tools.configurator.api.JonasConfigurator;
import org.ow2.jasmine.deployme.v2.generated.WebType;
import org.ow2.jasmine.deployme.v2.generated.OndemandType;
import org.ow2.jasmine.deployme.v2.generated.ConnectorsType;
import org.ow2.jasmine.deployme.v2.generated.HttpType;
import org.ow2.jasmine.deployme.v2.generated.HttpsType;
import org.ow2.jasmine.deployme.v2.generated.AjpType;

/**
 * Web module
 */
public class Web extends AbstractDeploymeModule {

    /**
     * JOnAS service
     */
    public static String JONAS_SERVICE = "web";

    /**
     * {@inheritDoc}
     */
    public boolean isSupport(final Object configuration) {
        return WebType.class.isInstance(configuration);
    }

    /**
     * {@inheritDoc}
     */
    public void applyConfiguration(final JonasConfigurator configurator, final Object object) throws UnsupportDeploymeModuleException {
        if (isSupport(object)) {
            WebType configuration = WebType.class.cast(object);
            if (configuration != null) {
                final ConnectorsType connectors = configuration.getConnectors();
                final AjpType ajp = connectors.getAjp();
                if (ajp != null) {
                    configurator.setAjpConnectorActivation(true);
                    final String ajpPort = String.valueOf(ajp.getPort());
                    if (ajpPort != null) {
                        configurator.setAjpPort(ajpPort);
                    }
                } else {
                    configurator.setAjpConnectorActivation(false);
                }
                final HttpType http = connectors.getHttp();
                if (http != null) {
                    configurator.setHttpConnectorActivation(true);
                    final String httpPort = String.valueOf(http.getPort());
                    if (httpPort != null) {
                        configurator.setHttpPort(httpPort);
                    }
                } else {
                    configurator.setHttpConnectorActivation(false);
                }
                final HttpsType https = connectors.getHttps();
                if (https != null) {
                    configurator.setHttpsConnectorActivation(true);
                    final String httpsPort = String.valueOf(https.getPort());
                    if (httpsPort != null) {
                        configurator.setHttpsPort(httpsPort);
                    }
                    final String httpsKeystoreFile = https.getKeystoreFile();
                    if (httpsKeystoreFile != null) {
                        configurator.setHttpsKeystoreFile(httpsKeystoreFile);
                    }
                    final String httpsKeystorePass = https.getKeystorePass();
                    if (httpsKeystorePass != null) {
                        configurator.setHttpsKeystorePass(httpsKeystorePass);
                    }
                } else {
                    configurator.setHttpsConnectorActivation(false);
                }
                final OndemandType ondemand = configuration.getOndemand();
                if (ondemand != null) {
                    configurator.setWebOndemandActivation(true);
                    final String webOndemandRedirectPort = String.valueOf(ondemand.getRedirectPort());
                    if (webOndemandRedirectPort != null) {
                        configurator.setWebOndemandRedirectPort(webOndemandRedirectPort);
                    }
                } else {
                    configurator.setWebOndemandActivation(false);
                }
            }
        } else {
            throw new UnsupportDeploymeModuleException("Object " + object.getClass().getName() + " is not support");
        }
    }

    /**
     * {@inheritDoc}
     */
    public String getJOnASService() {
        return JONAS_SERVICE;
    }
}
